
options = (
    ('registration-cypher-seed',
     {'type' : 'string',
      'default': u"this is my dummy registration cypher seed",
      'help': 'seed used to cypher registration data in confirmation email link',
      'group': 'registration', 'inputlevel': 2,
      }),
    )
